@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 use Dist::Zilla 4 ();
 
@@ -196,7 +196,7 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
@@ -341,7 +341,7 @@ use warnings;
 use Test::More tests => 1;
 
 use ExtUtils::MakeMaker;
-use File::Spec::Functions;
+use File::Spec;
 use List::Util qw/max first/;
 use Scalar::Util qw/blessed/;
 
@@ -443,7 +443,7 @@ for my $phase ( qw(configure build test runtime develop) ) {
             my $file = $mod;
             $file =~ s{::}{/}g;
             $file .= ".pm";
-            my $prefix = first { -e catfile($_, $file) } @INC;
+            my $prefix = first { -e File::Spec->catfile($_, $file) } @INC;
 
             my $want = $req_hash->{$phase}{$type}{$mod};
             $want = "undef" unless defined $want;
@@ -452,7 +452,7 @@ for my $phase ( qw(configure build test runtime develop) ) {
             my $req_string = $want eq 'any' ? 'any version required' : "version '$want' required";
 
             if ($prefix) {
-                my $have = MM->parse_version( catfile($prefix, $file) );
+                my $have = MM->parse_version( File::Spec->catfile($prefix, $file) );
                 $have = "undef" unless defined $have;
                 push @reports, [$mod, $want, $have];
 
